@@ -8,6 +8,9 @@ class Settings(BaseSettings):
     BACKEND_CORS_ORIGINS: List[AnyHttpUrl] = []
     OCPI_HOST: str = 'www.example.com'
     OCPI_PREFIX: str = 'ocpi'
+    PUSH_PREFIX: str = 'push'
+    COUNTRY_CODE: str = 'US'
+    PARTY_ID: str = 'NON'
 
     @classmethod
     @validator("BACKEND_CORS_ORIGINS", pre=True)
