@@ -7,3 +7,8 @@ class OCPIError(Exception):
 class AuthorizationOCPIError(OCPIError):
     def __str__(self):
         return 'Your authorization token is invalid.'
+
+
+class NotFoundOCPIError(OCPIError):
+    def __str__(self):
+        return 'Object not found.'
