@@ -1,24 +1,23 @@
 from typing import Any, List
 
-from fastapi import FastAPI, APIRouter, Request, HTTPException
+from fastapi import FastAPI, Request, HTTPException
+from fastapi.responses import JSONResponse
 from fastapi.middleware.cors import CORSMiddleware
+from pydantic import ValidationError
 from starlette.middleware.base import BaseHTTPMiddleware, RequestResponseEndpoint
 
-from py_ocpi.credentials.v_2_2_1.api import cpo_router as credentials_cpo_2_2_1_router
-from py_ocpi.locations.v_2_2_1.api import cpo_router as locations_cpo_2_2_1_router
-from py_ocpi.sessions.v_2_2_1.api import cpo_router as sessions_cpo_2_2_1_router
-from py_ocpi.commands.v_2_2_1.api import cpo_router as commands_cpo_2_2_1_router
-from py_ocpi.tariffs.v_2_2_1.api import cpo_router as tariffs_cpo_2_2_1_router
-from py_ocpi.tokens.v_2_2_1.api import cpo_router as tokens_cpo_2_2_1_router
-from py_ocpi.cdrs.v_2_2_1.api import cpo_router as cdrs_cpo_2_2_1_router
-from py_ocpi.versions.api import router as versions_router
-from py_ocpi.versions.enums import VersionNumber
-from py_ocpi.versions.schemas import Version
+from py_ocpi.modules.versions.api import router as versions_router, versions_v_2_2_1_router
+from py_ocpi.modules.versions.enums import VersionNumber
+from py_ocpi.modules.versions.schemas import Version
 from py_ocpi.core.dependencies import get_crud, get_adapter, get_versions
+from py_ocpi.core import status
 from py_ocpi.core.enums import RoleEnum
 from py_ocpi.core.config import settings
 from py_ocpi.core.data_types import URL
-from py_ocpi.core.exceptions import AuthorizationOCPIError
+from py_ocpi.core.schemas import OCPIResponse
+from py_ocpi.core.exceptions import AuthorizationOCPIError, NotFoundOCPIError
+from py_ocpi.core.push import http_router as http_push_router, websocket_router as websocket_push_router
+from py_ocpi.routers import v_2_2_1_cpo_router, v_2_2_1_emsp_router
 
 
 class ExceptionHandlerMiddleware(BaseHTTPMiddleware):
@@ -30,6 +29,15 @@ class ExceptionHandlerMiddleware(BaseHTTPMiddleware):
             response = await call_next(request)
         except AuthorizationOCPIError as e:
             raise HTTPException(403, str(e)) from e
+        except NotFoundOCPIError as e:
+            raise HTTPException(404, str(e)) from e
+        except ValidationError:
+            response = JSONResponse(
+                OCPIResponse(
+                    data=[],
+                    **status.OCPI_3000_GENERIC_SERVER_ERROR,
+                ).dict()
+            )
         return response
 
 
@@ -38,6 +46,8 @@ def get_application(
     roles: List[RoleEnum],
     crud: Any,
     adapter: Any,
+    http_push: bool = False,
+    websocket_push: bool = False,
 ) -> FastAPI:
     _app = FastAPI(
         title=settings.PROJECT_NAME,
@@ -53,39 +63,35 @@ def get_application(
         allow_headers=["*"],
     )
     _app.add_middleware(ExceptionHandlerMiddleware)
+
+    _app.include_router(
+        versions_router,
+        prefix=f'/{settings.OCPI_PREFIX}',
+    )
+
+    if http_push:
+        _app.include_router(
+            http_push_router,
+            prefix=f'/{settings.PUSH_PREFIX}',
+        )
+
+    if websocket_push:
+        _app.include_router(
+            websocket_push_router,
+            prefix=f'/{settings.PUSH_PREFIX}',
+        )
+
     versions = []
+
     if VersionNumber.v_2_2_1 in version_numbers:
         _app.include_router(
-            versions_router,
+            versions_v_2_2_1_router,
             prefix=f'/{settings.OCPI_PREFIX}',
         )
-        if RoleEnum.cpo in roles:
-            _cpo_router = APIRouter(
-            )
-            _cpo_router.include_router(
-                locations_cpo_2_2_1_router
-            )
-            _cpo_router.include_router(
-                credentials_cpo_2_2_1_router
-            )
-            _cpo_router.include_router(
-                sessions_cpo_2_2_1_router
-            )
-            _cpo_router.include_router(
-                commands_cpo_2_2_1_router
-            )
-            _cpo_router.include_router(
-                tariffs_cpo_2_2_1_router
-            )
-            _cpo_router.include_router(
-                tokens_cpo_2_2_1_router
-            )
-            _cpo_router.include_router(
-                cdrs_cpo_2_2_1_router
-            )
 
+        if RoleEnum.cpo in roles:
             _app.include_router(
-                _cpo_router,
+                v_2_2_1_cpo_router,
                 prefix=f'/{settings.OCPI_PREFIX}/cpo/{VersionNumber.v_2_2_1}',
                 tags=['CPO']
             )
@@ -97,6 +103,20 @@ def get_application(
                 ).dict(),
             )
 
+        if RoleEnum.emsp in roles:
+            _app.include_router(
+                v_2_2_1_emsp_router,
+                prefix=f'/{settings.OCPI_PREFIX}/emsp/{VersionNumber.v_2_2_1}',
+                tags=['EMSP']
+            )
+
+            versions.append(
+                Version(
+                    version=VersionNumber.v_2_2_1,
+                    url=URL(f'https://{settings.OCPI_HOST}/{settings.OCPI_PREFIX}/emsp/{VersionNumber.v_2_2_1}')
+                ).dict(),
+            )
+
     def override_get_crud():
         return crud
 
